// src/configs/chains.ts
var AssetChainMainnet = {
  id: 42420,
  name: "Asset Chain Mainnet",
  nativeCurrency: { name: "assetchain", symbol: "RWA", decimals: 18 },
  rpcUrls: {
    default: { http: ["https://mainnet-rpc.assetchain.org"] }
  },
  blockExplorers: {
    default: { name: "assetchain", url: "https://scan.assetchain.org" }
  }
};
var AssetChainTestnet = {
  id: 42421,
  name: "Asset Chain Testnet",
  nativeCurrency: { name: "assetchain", symbol: "RWA", decimals: 18 },
  rpcUrls: {
    default: { http: ["https://testnet-rpc.assetchain.org"] }
  },
  blockExplorers: {
    default: { name: "assetchain", url: "https://testnet-scan.assetchain.org" }
  }
};

// src/configs/networks.ts
var NETWORKS = {
  "assetchain_mainnet": {
    name: "Asset Chain Mainnet",
    addressType: "hex",
    chainId: 42420,
    currency: "RWA",
    explorerUrl: "https://scan.assetchain.org",
    rpcUrl: "https://mainnet-rpc.assetchain.org"
  },
  "assetchain_testnet": {
    name: "Asset Chain Testnet",
    addressType: "hex",
    chainId: 42421,
    currency: "RWA",
    explorerUrl: "https://testnet-scan.assetchain.org",
    rpcUrl: "https://testnet-rpc.assetchain.org"
  },
  "ton_mainnet": {
    name: "TON Mainnet",
    addressType: "base64",
    chainId: 1,
    currency: "TON",
    explorerUrl: "https://tonscan.org",
    rpcUrl: "https://ton-rpc.org"
  },
  "eth": {
    id: "eip155:1",
    chainNamespace: "eip155",
    name: "Ethereum",
    addressType: "hex",
    chainId: 1,
    currency: "ETH",
    explorerUrl: "https://etherscan.io",
    rpcUrl: "https://ethereum.org"
  }
};

// src/configs/index.ts
var configs = {
  NETWORKS,
  AssetChainMainnet,
  AssetChainTestnet
};

// src/pages/App.tsx
import { createContext, useEffect as useEffect3, useState as useState2 } from "react";

// src/utils/logConsole.tsx
var debugMode = false;
var logConsole = (...args) => {
  if (debugMode) {
    return console.log(...args);
  }
  return;
};

// src/hooks/useTonWallet.ts
import {
  useTonAddress,
  useTonConnectModal,
  useTonConnectUI
} from "@tonconnect/ui-react";
import { useContext, useEffect } from "react";
import TonWeb from "tonweb";
var tonWeb = new TonWeb();
var useTonWallet = () => {
  const { state, open, close } = useTonConnectModal();
  const [tonConnectUI] = useTonConnectUI();
  const userFriendlyAddress = useTonAddress();
  const rawAddress = useTonAddress(false);
  const dashboardContext = useContext(DashboardContext);
  if (!dashboardContext) {
    throw new Error("useDashboard Context must be used within a DashboardProvider");
  }
  const { tonConnected, setTonConnected, setSelectedWallet, setProcessing } = dashboardContext;
  const selectWallet = (wallet_) => {
    const wallet = wallet_.toLocaleLowerCase();
    logConsole({ wallet });
    if (wallet == "assetchain") {
      setSelectedWallet(NETWORKS.assetchain_mainnet);
    }
    if (wallet == "ton") {
      setSelectedWallet(NETWORKS.ton_mainnet);
    }
    if (wallet == "no_wallet") {
      setSelectedWallet();
    }
  };
  useEffect(() => {
    logConsole({ state });
    if (state.closeReason == "action-cancelled") {
      setTonConnected(false);
    }
    if (state.closeReason == "wallet-selected") {
      setTonConnected(true);
      selectWallet("ton");
    }
    if (state.closeReason == null && userFriendlyAddress.length) {
      setTonConnected(true);
    }
    if (state.closeReason == "action-cancelled" && !userFriendlyAddress.length) {
      setTonConnected(false);
      selectWallet("no_wallet");
    }
  }, [state]);
  const connectWallet = async () => {
    setProcessing(true);
    try {
      selectWallet("ton");
      await open();
      logConsole({ userFriendlyAddress, rawAddress });
    } catch (error) {
      logConsole({ error });
    }
    setProcessing(false);
  };
  const disconnectWallet = async () => {
    try {
      if (userFriendlyAddress.length) {
        await tonConnectUI.disconnect();
        await close();
        setTonConnected(false);
        setTonConnected(false);
        setSelectedWallet();
      } else {
        logConsole({ message: "Connect wallet" });
        setTonConnected(false);
      }
    } catch (error) {
      logConsole({ error });
    }
  };
  const sendTransaction2 = async (txParams) => {
    try {
      txParams.from = userFriendlyAddress;
      const value = tonWeb.utils.toNano(txParams.value);
      logConsole({ value });
      const tx = await tonConnectUI.sendTransaction({
        validUntil: Date.now() + 1e6,
        messages: [
          {
            address: txParams.to,
            amount: value.toString()
          }
        ]
      });
      return tx;
    } catch (error) {
      console.error("Transaction failed" + error.message);
    }
  };
  return {
    connectWallet,
    disconnectWallet,
    sendTransaction: sendTransaction2,
    userFriendlyAddress,
    tonConnected,
    state
  };
};

// src/hooks/useEvmWallet.ts
import { useEffect as useEffect2 } from "react";
import {
  getAccount,
  connect,
  disconnect,
  sendTransaction,
  reconnect,
  switchChain
} from "@wagmi/core";
import { parseEther, parseGwei } from "viem";

// src/configs/wagmiConfig.ts
import { http, createConfig, injected } from "@wagmi/core";
import { coinbaseWallet } from "@wagmi/connectors";
var coinBaseOptions = {
  appName: "Asset Chain Starter Kit"
};
var coinbaseConfig = coinbaseWallet(coinBaseOptions);
var wagmiConfig = createConfig({
  chains: [AssetChainMainnet, AssetChainTestnet],
  connectors: [coinbaseConfig, injected()],
  ssr: true,
  transports: {
    [AssetChainMainnet.id]: http(),
    [AssetChainTestnet.id]: http()
  }
});

// src/hooks/useEvmWallet.ts
import { metaMask, walletConnect } from "@wagmi/connectors";

// src/hooks/index.ts
import { useContext as useContext2 } from "react";
var useAssetChainConnect = () => {
  const context = useContext2(DashboardContext);
  if (!context) {
    throw new Error("useAssetChainConnect must be used within AssetChainKit");
  }
  return context;
};

// src/hooks/useEvmWallet.ts
var useEvmWallet = ({ projectId, infuraApiKey, metadata, network }) => {
  const metamaskOptions = {
    enableAnalytics: true,
    extensionOnly: false,
    infuraAPIKey: infuraApiKey,
    useDeeplink: true
  };
  const walletConnectOptions = {
    projectId,
    metadata,
    isNewChainsStale: true,
    disableProviderPing: false,
    customStoragePrefix: "wagmi",
    qrModalOptions: {
      themeMode: "light"
    }
  };
  const metaMaskConfig = metaMask(metamaskOptions);
  const walletConnectConfig = walletConnect(walletConnectOptions);
  const {
    address,
    chain,
    chainId,
    connector,
    isConnecting,
    status,
    isConnected
  } = getAccount(wagmiConfig);
  const defaultConnector = walletConnectConfig;
  const defaultChainId = network.id == 42420 ? AssetChainMainnet.id : AssetChainTestnet.id;
  const {
    evmConnected,
    setEvmConnected,
    setSelectedWallet,
    selectedWallet,
    setProcessing
  } = useAssetChainConnect();
  useEffect2(() => {
    logConsole({
      evmState: status,
      address,
      connector,
      isConnecting,
      isConnected
    });
    const wallet = status === "connected" || isConnected ? "assetchain" : "no_wallet";
    setEvmConnected(status === "connected" || isConnected);
    selectWallet(wallet);
  }, [status, isConnected]);
  const selectWallet = (wallet) => {
    switch (wallet.toLowerCase()) {
      case "assetchain":
        setSelectedWallet(NETWORKS.assetchain_mainnet);
        break;
      case "ton":
        setSelectedWallet(NETWORKS.ton_mainnet);
        break;
      default:
        setSelectedWallet(void 0);
    }
  };
  const connectEvmWallet = async () => {
    setProcessing(true);
    try {
      if (!isConnected) {
        logConsole("Connect EVM wallet");
        const result = await connect(wagmiConfig, { connector: defaultConnector, chainId: defaultChainId });
        if (result) {
          logConsole({ result });
          setEvmConnected(true);
          selectWallet("assetchain");
        }
      } else {
        logConsole("Wallet connected");
        selectWallet("assetchain");
      }
    } catch (error) {
      logConsole({ error });
    }
    setProcessing(false);
  };
  const disconnectEvmWallet = async () => {
    try {
      await disconnect(wagmiConfig);
      setEvmConnected(false);
    } catch (error) {
      logConsole({ error });
    }
  };
  const sendTransactionEvm = async (txParams) => {
    try {
      if (defaultChainId !== chainId) {
        logConsole("ChainId mismatch");
        await switchChain(wagmiConfig, { chainId: defaultChainId });
        return;
      }
      const result = await sendTransaction(wagmiConfig, {
        to: txParams.to,
        gas: parseGwei("20"),
        value: parseEther(txParams.value)
      });
      if (result) {
        logConsole({ sendTransactionEvm: result });
      }
      return result;
    } catch (error) {
      console.error({ error });
      logConsole("Something went wrong");
    }
  };
  const allowReconnect = async () => {
    try {
      const result = await reconnect(wagmiConfig, {
        connectors: [defaultConnector]
      });
      if (result) {
        logConsole({ allowReconnect: result });
      }
    } catch (error) {
      logConsole({ allowReconnectError: error });
    }
  };
  useEffect2(() => {
    if (!isConnected) {
      allowReconnect();
    }
  }, [isConnected]);
  return {
    connectEvmWallet,
    disconnectEvmWallet,
    sendTransactionEvm,
    evmAddress: address,
    isConnected,
    isConnecting
  };
};

// src/pages/App.tsx
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { WagmiProvider } from "wagmi";

// src/utils/concatAddress.ts
var concatAddress = (address) => address ? `${address.slice(0, 4)}...${address.slice(-4)}` : "";

// src/icons/AssetConnect.png
var AssetConnect_default = "./AssetConnect-MK2Q52LJ.png";

// src/icons/tonlogo.png
var tonlogo_default = "./tonlogo-JX77XVQA.png";

// src/icons/whiteassetchainlogo.png
var whiteassetchainlogo_default = "./whiteassetchainlogo-SWSAD2LT.png";

// src/icons/AssetchainLoading.png
var AssetchainLoading_default = "./AssetchainLoading-HWO4UG4P.png";

// src/icons/arrow-right.png
var arrow_right_default = "./arrow-right-OMRE6WGH.png";

// src/icons/Metamask.png
var Metamask_default = "./Metamask-TFGOMGBI.png";

// src/pages/Modal.tsx
import { Fragment, jsx, jsxs } from "react/jsx-runtime";
var AssetChainModal = ({
  projectId,
  infuraApiKey,
  metadata,
  network
}) => {
  const { connectWallet, disconnectWallet, userFriendlyAddress } = useTonWallet();
  const { connectEvmWallet, evmAddress } = useEvmWallet({ projectId, infuraApiKey, metadata, network });
  const assetChainConnect = useAssetChainConnect();
  const {
    tonConnected,
    evmConnected,
    disableEvm,
    toggleModal,
    disableTon,
    processing,
    noTon
  } = assetChainConnect;
  const address = concatAddress(userFriendlyAddress);
  const addressEVM = concatAddress(evmAddress || "");
  return /* @__PURE__ */ jsx("div", { className: "fixed inset-0 bg-opacity-50 flex justify-center items-end z-50", children: /* @__PURE__ */ jsxs("div", { className: "modal-glow pt-6 w-full md:w-1/2 rounded-t-lg", children: [
    /* @__PURE__ */ jsxs("span", { className: "flex justify-between mb-4 pl-4 pr-4", children: [
      /* @__PURE__ */ jsx("h2", { className: "text-lg font-bold mb-4", children: /* @__PURE__ */ jsx("img", { src: AssetConnect_default, alt: "logo", className: "w-48" }) }),
      /* @__PURE__ */ jsx(
        "h2",
        {
          onClick: toggleModal,
          className: "text-lg text-center mb-4 h-[30px] w-[30px] rounded-full text-[#537AA5] bg-gray-700 cursor-pointer",
          children: "X"
        }
      )
    ] }),
    /* @__PURE__ */ jsx("div", { className: "bg-[#0B131E] h-auto rounded-t-[30px] p-6 pb-1 min-full", children: /* @__PURE__ */ jsxs("div", { className: "h-auto text-center", children: [
      /* @__PURE__ */ jsx("h1", { className: "text-center font-bold text-white text-2xl", children: "Select Wallet" }),
      /* @__PURE__ */ jsx("span", { className: "text-center font-bold text-sm text-gray-400", children: "Connect your wallet or Dapp on Asset Chain network or connect to TON network" }),
      /* @__PURE__ */ jsxs("div", { children: [
        /* @__PURE__ */ jsx("div", { className: "mt-6", children: !disableEvm && /* @__PURE__ */ jsx(Fragment, { children: !processing && !evmConnected ? /* @__PURE__ */ jsxs(
          "span",
          {
            onClick: connectEvmWallet,
            className: "bg-[#0049e7] flex mt-4 px-7 rounded-lg font-bold py-4 justify-between text-white",
            children: [
              /* @__PURE__ */ jsx("div", { className: "flex text-center", children: /* @__PURE__ */ jsx(
                "img",
                {
                  className: "w-44",
                  src: whiteassetchainlogo_default,
                  alt: "spin"
                }
              ) }),
              /* @__PURE__ */ jsx("span", { className: "mt-1 text-light text-xl", children: /* @__PURE__ */ jsx("img", { src: arrow_right_default, alt: "" }) })
            ]
          }
        ) : /* @__PURE__ */ jsx("span", { className: "flex flex-col items-center mt-4 font-bold text-center text-white", children: !evmConnected ? /* @__PURE__ */ jsxs(Fragment, { children: [
          /* @__PURE__ */ jsxs("span", { className: "relative bg-[#0049e7] rounded-full w-24 h-24 flex items-center justify-center", children: [
            /* @__PURE__ */ jsx("div", { className: "spinning-gradient absolute inset-0 rounded-full z-0" }),
            /* @__PURE__ */ jsx(
              "img",
              {
                className: "relative w-24 h-24 object-contain z-10 rounded-full",
                src: AssetchainLoading_default,
                alt: ""
              }
            )
          ] }),
          /* @__PURE__ */ jsx("span", { className: "text-md font-bold text-center mt-4 text-gray-400", children: processing ? "Connecting" : "Asset Chain" })
        ] }) : /* @__PURE__ */ jsxs(Fragment, { children: [
          /* @__PURE__ */ jsx("span", { className: "text-center", children: /* @__PURE__ */ jsx(
            "img",
            {
              className: "w-24 h-24 rounded-lg",
              src: Metamask_default,
              alt: ""
            }
          ) }),
          /* @__PURE__ */ jsxs("span", { className: "grid text-md font-bold text-center mt-4 text-gray-400", children: [
            /* @__PURE__ */ jsx("span", { className: "text-sm font-light", children: "Metamask on Asset Chain" }),
            evmAddress && addressEVM
          ] })
        ] }) }) }) }),
        !noTon && /* @__PURE__ */ jsx("div", { className: "mt-6 text-center", children: !disableTon && /* @__PURE__ */ jsx("div", { children: !tonConnected ? /* @__PURE__ */ jsxs(
          "span",
          {
            onClick: connectWallet,
            className: "flex flex-col items-center justify-center",
            children: [
              /* @__PURE__ */ jsx(
                "img",
                {
                  alt: "tonimage",
                  src: tonlogo_default,
                  className: "w-14 h-14 rounded-full"
                }
              ),
              /* @__PURE__ */ jsx("span", { className: "font-bold text-md mt-2 text-white", children: "Ton" })
            ]
          }
        ) : /* @__PURE__ */ jsxs(
          "span",
          {
            onClick: disconnectWallet,
            className: "flex flex-col items-center justify-center",
            children: [
              /* @__PURE__ */ jsx(
                "img",
                {
                  alt: "tonimage",
                  src: tonlogo_default,
                  className: "w-14 h-14 rounded-full"
                }
              ),
              /* @__PURE__ */ jsx("span", { className: "font-bold text-sm mt-1 text-white", children: address || "" })
            ]
          }
        ) }) })
      ] }),
      (!evmConnected || !tonConnected) && /* @__PURE__ */ jsx("div", { className: "mt-4 mb-2 border-t border-t-[#55687c] pb-1", children: /* @__PURE__ */ jsxs("span", { className: "text-xs font-bold text-[#55687c]", children: [
        "AssetConnect is Asset Chain",
        "\u2019",
        "s native wallet connection toolkit designed to seamlessly link any wallet and DApp within the Asset Chain ecosystem."
      ] }) })
    ] }) })
  ] }) });
};
var Modal_default = AssetChainModal;

// src/pages/App.tsx
import { TonConnectUIProvider } from "@tonconnect/ui-react";
import { jsx as jsx2 } from "react/jsx-runtime";
var queryClientOptions = new QueryClient({
  defaultOptions: {
    queries: {
      gcTime: 1e3 * 60 * 60 * 24
    }
  }
});
var DashboardContext = createContext({
  tonConnected: false,
  setTonConnected: () => {
  },
  evmConnected: false,
  setEvmConnected: () => {
  },
  selectedWallet: {},
  setSelectedWallet: () => {
  },
  disableTon: false,
  setDisableTon: () => {
  },
  disableEvm: false,
  setDisableEvm: () => {
  },
  processing: false,
  setProcessing: () => {
  },
  isConnected: false,
  setIsConnected: () => {
  },
  walletConnected: false,
  setWalletConnected: () => {
  },
  handleSendTransaction: () => {
  },
  isConnecting: false,
  allowDisconnect: () => {
  },
  toggleModal: () => {
  },
  open: () => {
  },
  close: () => {
  },
  noTon: false,
  evmConnect: {
    connectEvmWallet: async () => {
    },
    disconnectEvmWallet: async () => {
    },
    sendTransactionEvm: async () => {
    },
    evmAddress: void 0,
    isConnected: false,
    isConnecting: false
  }
});
function App({
  children,
  manifestUrl,
  projectId,
  infuraApiKey,
  metadata,
  defaultConnector,
  network,
  noTon
}) {
  const [tonConnected, setTonConnected] = useState2(false);
  const [evmConnected, setEvmConnected] = useState2(false);
  const [selectedWallet, setSelectedWallet] = useState2(
    NETWORKS.assetchain_mainnet
  );
  const [disableTon, setDisableTon] = useState2(false);
  const [disableEvm, setDisableEvm] = useState2(false);
  const [processing, setProcessing] = useState2(false);
  const [isConnected, setIsConnected] = useState2(false);
  const [walletConnected, setWalletConnected] = useState2(false);
  const [isModalOpen, setIsModalOpen] = useState2(false);
  const [isSendModalOpen, setIsSendModalOpen] = useState2(false);
  const toggleModal = () => setIsModalOpen(!isModalOpen);
  const [modalState, setModalState] = useState2({ status: "closed" });
  const openModal = () => {
    setModalState({ status: "opened" });
    toggleModal();
  };
  const closeModal = () => {
    setModalState({ status: "closed" });
    toggleModal();
  };
  const { disconnectWallet, sendTransaction: sendTransaction2 } = useTonWallet();
  const evmConnect = useEvmWallet({
    projectId,
    infuraApiKey,
    metadata,
    network
  });
  const { disconnectEvmWallet, sendTransactionEvm } = evmConnect;
  const onlyOneWallet = () => {
    if (tonConnected) {
      setDisableEvm(true);
    }
    if (evmConnected) {
      setDisableTon(true);
    }
  };
  const selectWallet = (wallet_) => {
    const wallet = wallet_.toLocaleLowerCase();
    logConsole({ wallet });
    if (wallet == "assetchain") {
      setSelectedWallet(NETWORKS.assetchain_mainnet);
    }
    if (wallet == "ton") {
      setSelectedWallet(NETWORKS.ton_mainnet);
    }
  };
  useEffect3(() => {
    onlyOneWallet();
  }, [tonConnected, evmConnected]);
  useEffect3(() => {
    if (tonConnected || evmConnected) {
      setWalletConnected(true);
      if (tonConnected) {
        selectWallet("ton");
      }
      if (evmConnected) {
        selectWallet("assetchain");
      }
    } else {
      setWalletConnected(false);
    }
    if (selectedWallet) {
      setWalletConnected(true);
    }
  }, [tonConnected, evmConnected, selectedWallet]);
  const allowDisconnect = async () => {
    if (!selectedWallet) return;
    const actions = {
      RWA: disconnectEvmWallet,
      TON: disconnectWallet
    };
    const currency = selectedWallet?.currency;
    if (currency && actions[currency]) {
      await actions[currency]();
      setDisableEvm(false);
      setDisableTon(false);
      setWalletConnected(false);
    }
  };
  const handleSendTransaction = async (amount, to) => {
    const sendAmount = amount;
    const recipientAddress = to;
    try {
      if (selectedWallet) {
        if (tonConnected || evmConnected) {
          if (selectedWallet.currency == "TON") {
            const tx = await sendTransaction2({
              value: sendAmount,
              to: recipientAddress
            });
            return tx;
          }
          if (selectedWallet.currency == "RWA") {
            const tx = await sendTransactionEvm({
              value: sendAmount,
              to: recipientAddress
            });
            return tx;
          }
        }
      } else {
        console.error("Connect a wallet first");
      }
    } catch (error) {
      logConsole({ error });
    }
  };
  return /* @__PURE__ */ jsx2(WagmiProvider, { config: wagmiConfig, children: /* @__PURE__ */ jsx2(QueryClientProvider, { client: queryClientOptions, children: /* @__PURE__ */ jsx2(TonConnectUIProvider, { manifestUrl, children: /* @__PURE__ */ jsx2(
    DashboardContext.Provider,
    {
      value: {
        setTonConnected,
        setEvmConnected,
        setSelectedWallet,
        setDisableTon,
        setDisableEvm,
        setProcessing,
        setIsConnected,
        setWalletConnected,
        disableEvm,
        disableTon,
        processing,
        walletConnected,
        handleSendTransaction,
        allowDisconnect,
        toggleModal,
        selectedWallet,
        evmConnected,
        tonConnected,
        isConnecting: processing,
        isConnected,
        open: openModal,
        close: closeModal,
        noTon,
        evmConnect
      },
      children: /* @__PURE__ */ jsx2(
        Modal_default,
        {
          projectId,
          infuraApiKey,
          metadata,
          network,
          children
        }
      )
    }
  ) }) }) });
}

// src/pages/index.tsx
import { TonConnectUIProvider as TonConnectUIProvider2 } from "@tonconnect/ui-react";
import { jsx as jsx3 } from "react/jsx-runtime";
function AssetChainKit({
  children,
  manifestUrl,
  projectId,
  infuraApiKey,
  metadata,
  defaultConnector,
  network,
  noTon
}) {
  return /* @__PURE__ */ jsx3("div", { children: /* @__PURE__ */ jsx3(TonConnectUIProvider2, { manifestUrl, children: /* @__PURE__ */ jsx3(
    App,
    {
      manifestUrl,
      projectId,
      infuraApiKey,
      metadata,
      defaultConnector,
      network,
      noTon,
      children
    }
  ) }) });
}

// src/utils/explorerLink.ts
function explorerLink(network, hash) {
  const rawLink = network.explorerUrl.concat("/tx/").concat(hash);
  const turncateLink = concatAddress(network.explorerUrl).concat("/tx/").concat(concatAddress(hash));
  return {
    rawLink,
    turncateLink
  };
}

// src/utils/onCopy.ts
var onCopy = async (text) => {
  try {
    await navigator.clipboard.writeText(text);
    console.log("Text copied");
  } catch (error) {
    console.log({ error });
  }
};

// src/utils/validateAddress.ts
function verifyAddress(address) {
  const hexRegex = /^0x[a-fA-F0-9]{40}$/;
  const base64Regex = /^[A-Za-z0-9+/=]{44}$/;
  if (hexRegex.test(address)) {
    return { address, type: "hex" };
  } else if (base64Regex.test(address)) {
    return { address, type: "base64" };
  } else {
    return { address, type: "invalid" };
  }
}

// src/test.ts
var sayHello = async () => {
  return "Asset Chain connect!";
};

// src/index.ts
import { TonConnectUIProvider as TonConnectUIProvider3 } from "@tonconnect/ui-react";
export {
  AssetChainKit,
  TonConnectUIProvider3 as TonConnectUIProvider,
  concatAddress,
  configs,
  explorerLink,
  onCopy,
  sayHello,
  useAssetChainConnect,
  useEvmWallet,
  useTonWallet,
  verifyAddress
};
